@@ -22,19 +22,19 @@ import importlib
 
 def str2bool(x):
     assert x in {"True", "False", "true", "false", "null"}
-    if x == "<null>":
+    if x == "null":
         return None
     return x.lower() == "true"
 
 
 def nullable_str(x):
-    if x == "<null>":
+    if x == "null":
         return None
     return x
 
 
 def str2int(x):
-    if x == "<null>":
+    if x == "null":
         return None
     return int(x)
 
@@ -316,6 +316,13 @@ def import_func(func_ident: str) -> Callable:
     return getattr(module, func)
 
 
+def import_attr(attr_ident: str):
+    lst = attr_ident.rsplit(".", 1)
+    module, cls = lst
+    module = importlib.import_module(module)
+    return getattr(module, cls)
+
+
 class Proxy:
     """Proxy object, can be used for delayed initialization"""
 
